geo2kml
~~~~~~~

Convert geoJson to KML format. Port from https://github.com/mapbox/tokml

Installation
============
``pip3 install geo2kml``

Usage
=====

  from geo2kml import to_kml

  kml_str = to_kml(geojson)
